@@ -6,36 +6,36 @@
 
 #include "KNSBackendTest.h"
 #include "utils.h"
-#include <KNSBackend.h>
-#include <resources/AbstractBackendUpdater.h>
-#include <resources/AbstractResource.h>
-#include <resources/ResourcesModel.h>
-#include <ReviewsBackend/AbstractReviewsBackend.h>
-#include <ReviewsBackend/Review.h>
-#include <ReviewsBackend/Rating.h>
 #include <Category/Category.h>
 #include <Category/CategoryModel.h>
 #include <DiscoverBackendsFactory.h>
+#include <KNSBackend.h>
 #include <QStandardPaths>
+#include <ReviewsBackend/AbstractReviewsBackend.h>
+#include <ReviewsBackend/Rating.h>
+#include <ReviewsBackend/Review.h>
+#include <resources/AbstractBackendUpdater.h>
+#include <resources/AbstractResource.h>
+#include <resources/ResourcesModel.h>
 
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
 
-QTEST_MAIN( KNSBackendTest )
+QTEST_MAIN(KNSBackendTest)
 
-KNSBackendTest::KNSBackendTest(QObject* parent)
+KNSBackendTest::KNSBackendTest(QObject *parent)
     : QObject(parent)
     , m_r(nullptr)
 {
     QStandardPaths::setTestModeEnabled(true);
     QDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)).removeRecursively();
 
-    ResourcesModel* model = new ResourcesModel(QStringLiteral("kns-backend"), this);
+    ResourcesModel *model = new ResourcesModel(QStringLiteral("kns-backend"), this);
     Q_ASSERT(!model->backends().isEmpty());
-    auto findTestBackend = [](AbstractResourcesBackend* backend) {
+    auto findTestBackend = [](AbstractResourcesBackend *backend) {
         return backend->name() == QLatin1String("discover_ktexteditor_codesnippets_core.knsrc");
     };
-    m_backend = kFilter<QVector<AbstractResourcesBackend*>>(model->backends(), findTestBackend).at(0);
+    m_backend = kFilter<QVector<AbstractResourcesBackend *>>(model->backends(), findTestBackend).at(0);
 
     if (!m_backend->isValid()) {
         qWarning() << "couldn't run the test";
@@ -45,19 +45,19 @@ KNSBackendTest::KNSBackendTest(QObject* parent)
     connect(m_backend->reviewsBackend(), &AbstractReviewsBackend::reviewsReady, this, &KNSBackendTest::reviewsArrived);
 }
 
-QVector<AbstractResource*> KNSBackendTest::getResources(ResultsStream* stream, bool canBeEmpty)
+QVector<AbstractResource *> KNSBackendTest::getResources(ResultsStream *stream, bool canBeEmpty)
 {
     Q_ASSERT(stream);
     Q_ASSERT(stream->objectName() != QLatin1String("KNS-void"));
     QSignalSpy spyResources(stream, &ResultsStream::destroyed);
-    QVector<AbstractResource*> resources;
-    connect(stream, &ResultsStream::resourcesFound, this, [&resources, stream](const QVector<AbstractResource*>& res) {
+    QVector<AbstractResource *> resources;
+    connect(stream, &ResultsStream::resourcesFound, this, [&resources, stream](const QVector<AbstractResource *> &res) {
         resources += res;
         Q_EMIT stream->fetchMore();
     });
     bool waited = spyResources.wait(10000);
     if (!waited) {
-        if (auto x = qobject_cast<AggregatedResultsStream*>(stream))
+        if (auto x = qobject_cast<AggregatedResultsStream *>(stream))
             qDebug() << "waited" << x->streams();
     }
     Q_ASSERT(waited);
@@ -65,7 +65,7 @@ QVector<AbstractResource*> KNSBackendTest::getResources(ResultsStream* stream, b
     return resources;
 }
 
-QVector<AbstractResource*> KNSBackendTest::getAllResources(AbstractResourcesBackend* backend)
+QVector<AbstractResource *> KNSBackendTest::getAllResources(AbstractResourcesBackend *backend)
 {
     AbstractResourcesBackend::Filters f;
     if (CategoryModel::global()->rootCategories().isEmpty())
@@ -83,14 +83,14 @@ void KNSBackendTest::testRetrieval()
     QVERIFY(!m_backend->isFetching() || spy.wait());
 
     const auto resources = getAllResources(m_backend);
-    foreach(AbstractResource* res, resources) {
+    foreach (AbstractResource *res, resources) {
         QVERIFY(!res->name().isEmpty());
         QVERIFY(!res->categories().isEmpty());
         QVERIFY(!res->origin().isEmpty());
         QVERIFY(!res->icon().isNull());
-//         QVERIFY(!res->comment().isEmpty());
-//         QVERIFY(!res->longDescription().isEmpty());
-//         QVERIFY(!res->license().isEmpty());
+        //     QVERIFY(!res->comment().isEmpty());
+        //     QVERIFY(!res->longDescription().isEmpty());
+        //     QVERIFY(!res->license().isEmpty());
         QVERIFY(res->homepage().isValid() && !res->homepage().isEmpty());
         QVERIFY(res->state() > AbstractResource::Broken);
         QVERIFY(res->addonsInformation().isEmpty());
@@ -107,14 +107,14 @@ void KNSBackendTest::testRetrieval()
 
 void KNSBackendTest::testReviews()
 {
-    const QVector<AbstractResource*> resources = getAllResources(m_backend);
-    AbstractReviewsBackend* rev = m_backend->reviewsBackend();
+    const QVector<AbstractResource *> resources = getAllResources(m_backend);
+    AbstractReviewsBackend *rev = m_backend->reviewsBackend();
     QVERIFY(!rev->hasCredentials());
-    foreach(AbstractResource* res, resources) {
-        Rating* r = rev->ratingForApplication(res);
+    foreach (AbstractResource *res, resources) {
+        Rating *r = rev->ratingForApplication(res);
         QVERIFY(r);
         QCOMPARE(r->packageName(), res->packageName());
-        QVERIFY(r->rating()>0 && r->rating()<=10);
+        QVERIFY(r->rating() > 0 && r->rating() <= 10);
     }
 
     auto res = resources.first();
@@ -123,7 +123,7 @@ void KNSBackendTest::testReviews()
     QVERIFY(spy.count() || spy.wait());
 }
 
-void KNSBackendTest::reviewsArrived(AbstractResource* r, const QVector<ReviewPtr>& revs)
+void KNSBackendTest::reviewsArrived(AbstractResource *r, const QVector<ReviewPtr> &revs)
 {
     m_r = r;
     m_revs = revs;
@@ -133,13 +133,15 @@ void KNSBackendTest::testResourceByUrl()
 {
     AbstractResourcesBackend::Filters f;
     f.resourceUrl = QUrl(QLatin1String("kns://") + m_backend->name() + QLatin1String("/api.kde-look.org/1136471"));
-    const QVector<AbstractResource*> resources = getResources(m_backend->search(f));
-    const QVector<QUrl> res = kTransform<QVector<QUrl>>(resources, [](AbstractResource* res){ return res->url(); });
+    const QVector<AbstractResource *> resources = getResources(m_backend->search(f));
+    const QVector<QUrl> res = kTransform<QVector<QUrl>>(resources, [](AbstractResource *res) {
+        return res->url();
+    });
     QCOMPARE(res.count(), 1);
     QCOMPARE(f.resourceUrl, res.constFirst());
 
     auto resource = resources.constFirst();
-    QVERIFY(!resource->isInstalled()); //Make sure .qttest is clean before running the test
+    QVERIFY(!resource->isInstalled()); // Make sure .qttest is clean before running the test
 
     QSignalSpy spy(resource, &AbstractResource::stateChanged);
     auto b = resource->backend();
@@ -154,9 +156,11 @@ void KNSBackendTest::testResourceByUrl()
 void KNSBackendTest::testResourceByUrlResourcesModel()
 {
     AbstractResourcesBackend::Filters filter;
-    filter.resourceUrl = QUrl(QStringLiteral("kns://plasmoids.knsrc/store.kde.org/1169537")); //Wrong domain
+    filter.resourceUrl = QUrl(QStringLiteral("kns://plasmoids.knsrc/store.kde.org/1169537")); // Wrong domain
 
     auto resources = getResources(ResourcesModel::global()->search(filter), true);
-    const QVector<QUrl> res = kTransform<QVector<QUrl>>(resources, [](AbstractResource* res){ return res->url(); });
+    const QVector<QUrl> res = kTransform<QVector<QUrl>>(resources, [](AbstractResource *res) {
+        return res->url();
+    });
     QCOMPARE(res.count(), 0);
 }
